import ajax from '../util/ajax'
import api from '../util/api'

export default {
  namespaced: true,
  state: {
    activity: {},
    user: '4',
    detail: {},
    myprofile: {},
    toplist: [],
    list: [],
  },
  mutations: {
    updateActivity (state, data) {
      state.activity = data || {}
    },
    updateUser (state, data) {
      state.user = data
    },
    updateDetail (state, data) {
      state.detail = data || {}
    },
    updateMine (state, data) {
      state.myprofile = data || {}
    },
    updateList (state, data) {
      const news = (data || []).filter(x => !(state.list || []).filter(y => y.MemberId === x.MemberId)[0])
      state.list = (state.list || []).concat(news)
    },
    updateTopList (state, data) {
      const news = (data || []).filter(x => !(state.toplist || []).filter(y => y.MemberId === x.MemberId)[0])
      state.toplist = (state.toplist || []).concat(news)
    },
  },
  actions: {
    getActivity ({ commit, state }, {actid}) {
      if (state.activity && state.activity.ActivityId == actid) {
        return Promise.resolve(state.activity)
      }

      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.info,
          urlData: {
            actid: actid,
          }
        }).then((res) => {
          commit('updateActivity', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getMine ({ commit, state }, payload) {
      if (state.myprofile && state.myprofile.MemberId) {
        return Promise.resolve(state.myprofile)
      }

      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.mime,
          urlData: {
            actid: payload.actid,
          },
        }).then((res) => {
          commit('updateMine', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getMember ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.detail,
          urlData: {
            actid: payload.actid,
            memberid: payload.memberid,
          },
        }).then((res) => {
          commit('updateDetail', res)
          resolve(res)
        }).catch(reject)
      })
    },
    vote (m, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.vote,
          urlData: {
            actid: payload.actid,
            memberid: payload.memberid,
          },
          queryData: {
            openid: payload.openid,
          }
        }).then((res) => {
          resolve(res)
        }).catch(reject)
      })
    },
    voteMember ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.registe,
          urlData: {
            actid: payload.actid,
          },
          queryData: {
            ...payload,
          }
        }).then((res) => {
          commit('updateDetail', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getUser ({ commit }, { code }) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.user,
          urlData: {
            code: code,
          },
        }).then((res) => {
          commit('updateUser', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.list,
          queryData: {
            ...payload,
            tab: 1,
          },
        }).then((res) => {
          commit('updateList', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getTopList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.list,
          queryData: {
            ...payload,
            tab: 2,
          },
        }).then((res) => {
          commit('updateTopList', res)
          resolve(res)
        }).catch(reject)
      })
    },
  }
}
